.. _installation-guide:

=============================================
Welcome to the passagemath Installation Guide
=============================================

This is the installation guide for passagemath, the free open-source mathematics software system.

`Installation from the provided binary wheels on PYPI <https://github.com/passagemath/passagemath?tab=readme-ov-file#full-installation-of-passagemath-from-binary-wheels-on-pypi>`__
is easy, just use ``pip install passagemath-standard`` to install.


.. toctree::
   :maxdepth: 2

   conda
   source
   meson
   launching
   troubles
